@@ -5,6 +5,7 @@ import base64
 import hashlib
 import json
 import re
+import sys
 import typing
 import uuid
 from contextlib import suppress
@@ -13,6 +14,7 @@ from datetime import timedelta
 import anyio
 import anyio.abc
 import typer
+from a2a.utils import AGENT_CARD_WELL_KNOWN_PATH
 from anyio import open_process
 from httpx import AsyncClient, HTTPError
 from tenacity import AsyncRetrying, retry_if_exception_type, stop_after_delay, wait_fixed
@@ -36,6 +38,7 @@ app = AsyncTyper()
 @app.command("build")
 async def build(
     context: typing.Annotated[str, typer.Argument(help="Docker context for the agent")] = ".",
+    dockerfile: typing.Annotated[str | None, typer.Option(help="Use custom dockerfile path")] = None,
     tag: typing.Annotated[str | None, typer.Option(help="Docker tag for the agent")] = None,
     multi_platform: bool | None = False,
     push: typing.Annotated[bool, typer.Option(help="Push the image to the target registry.")] = False,
@@ -49,12 +52,16 @@ async def build(
         await run_command(["which", "docker"], "Checking docker")
         image_id = "beeai-agent-build-tmp:latest"
         port = await find_free_port()
+        dockerfile_args = ("-f", dockerfile) if dockerfile else ()
 
-        await run_command(["docker", "build", context, "-t", image_id], "Building agent image")
+        await run_command(
+            ["docker", "build", context, *dockerfile_args, "-t", image_id],
+            "Building agent image",
+        )
 
-        response = None
+        agent_card = None
 
-        container_id = uuid.uuid4()
+        container_id = str(uuid.uuid4())
 
         with status("Extracting agent metadata"):
             async with (
@@ -72,11 +79,11 @@ async def build(
                         ):
                             with attempt:
                                 async with AsyncClient() as client:
-                                    resp = await client.get(f"http://localhost:{port}/agents", timeout=1)
+                                    resp = await client.get(
+                                        f"http://localhost:{port}{AGENT_CARD_WELL_KNOWN_PATH}", timeout=1
+                                    )
                                     resp.raise_for_status()
-                                    response = resp.json()
-                                    if "agents" not in response:
-                                        raise ValueError(f"Missing agents in response from server: {response}")
+                                    agent_card = resp.json()
                         process.terminate()
                         with suppress(ProcessLookupError):
                             process.kill()
@@ -89,7 +96,7 @@ async def build(
                         with suppress(ProcessLookupError):
                             process.kill()
 
-        context_hash = hashlib.sha256(context.encode()).hexdigest()[:6]
+        context_hash = hashlib.sha256((context + (dockerfile or "")).encode()).hexdigest()[:6]
         context_shorter = re.sub(r"https?://", "", context).replace(r".git", "")
         context_shorter = re.sub(r"[^a-zA-Z0-9_-]+", "-", context_shorter)[:32].lstrip("-") or "provider"
         tag = (tag or f"beeai.local/{context_shorter}-{context_hash}:latest").lower()
@@ -102,17 +109,22 @@ async def build(
                 ),
                 "--push" if push else "--load",
                 context,
+                *dockerfile_args,
                 "-t",
                 tag,
-                f"--label=beeai.dev.agent.yaml={base64.b64encode(json.dumps(response).encode()).decode()}",
+                f"--label=beeai.dev.agent.json={base64.b64encode(json.dumps(agent_card).encode()).decode()}",
             ],
             message="Adding agent labels to container",
             check=True,
         )
         console.print(f"✅ Successfully built agent: {tag}")
         if import_image:
-            from beeai_cli.commands.platform import import_image
+            from beeai_cli.commands.platform import get_driver
 
-            await import_image(tag, vm_name=vm_name)
+            driver = get_driver(vm_name=vm_name)
+            if (await driver.status()) != "running":
+                console.print("[red]BeeAI platform is not running.[/red]")
+                sys.exit(1)
+            await driver.import_image(tag)
 
-        return tag, response["agents"]
+        return tag, agent_card
