@@ -6,15 +6,16 @@ import functools
 import json
 import os
 import subprocess
-from collections.abc import AsyncIterable, Iterable
+import sys
+from collections.abc import AsyncIterator
 from contextlib import asynccontextmanager
 from contextvars import ContextVar
 from copy import deepcopy
-from enum import Enum
 from io import BytesIO
-from typing import TYPE_CHECKING, Any, Optional, cast
+from typing import TYPE_CHECKING, Any
 
 import anyio
+import anyio.abc
 import typer
 import yaml
 from anyio import create_task_group
@@ -23,6 +24,7 @@ from jsf import JSF
 from prompt_toolkit import PromptSession
 from prompt_toolkit.shortcuts import CompleteStyle
 from pydantic import BaseModel
+from rich.console import Capture
 from rich.text import Text
 
 from beeai_cli.console import console, err_console
@@ -32,11 +34,6 @@ if TYPE_CHECKING:
     from prompt_toolkit.validation import Validator
 
 
-class VMDriver(str, Enum):
-    lima = "lima"
-    wsl = "wsl"
-
-
 def format_model(value: BaseModel | list[BaseModel]) -> str:
     if isinstance(value, BaseException):
         return str(value)
@@ -71,20 +68,13 @@ def check_json(value: Any) -> dict[str, Any]:
         raise typer.BadParameter(f"Invalid JSON '{value}'") from e
 
 
-def omit[DictType: dict](dict: DictType, keys: Iterable[str]) -> DictType:
-    return {key: value for key, value in dict.items() if key not in keys}
-
-
-def filter_dict[T, V](map: dict[str, T | V], value_to_exclude: V = None) -> dict[str, V]:
-    """Remove entries with unwanted values (None by default) from dictionary."""
-    return {filter: value for filter, value in map.items() if value is not value_to_exclude}
-
-
 @functools.cache
 def generate_schema_example(json_schema: dict[str, Any]) -> dict[str, Any]:
     json_schema = deepcopy(remove_nullable(json_schema))
 
     def _make_fakes_better(schema: dict[str, Any] | None):
+        if not schema:
+            return
         match schema["type"]:
             case "array":
                 schema["maxItems"] = 3
@@ -120,9 +110,9 @@ prompt_session = None
 
 def prompt_user(
     prompt: str | None = None,
-    completer: Optional["Completer"] = None,
+    completer: "Completer | None" = None,
     placeholder: str | None = None,
-    validator: Optional["Validator"] = None,
+    validator: "Validator | None" = None,
     open_autocomplete_by_default=False,
 ) -> str:
     global prompt_session
@@ -161,7 +151,7 @@ def prompt_user(
 
 
 @asynccontextmanager
-async def capture_output(process: anyio.abc.Process, stream_contents: list | None = None) -> AsyncIterable[TaskGroup]:
+async def capture_output(process: anyio.abc.Process, stream_contents: list | None = None) -> AsyncIterator[TaskGroup]:
     async def receive_logs(stream: ByteReceiveStream, index=0):
         buffer = BytesIO()
         async for chunk in stream:
@@ -181,12 +171,11 @@ async def capture_output(process: anyio.abc.Process, stream_contents: list | Non
 async def run_command(
     command: list[str],
     message: str,
-    env: dict | None = None,
+    env: dict[str, str] | None = None,
     cwd: str = ".",
     check: bool = True,
-    ignore_missing: bool = False,
     input: bytes | None = None,
-) -> subprocess.CompletedProcess:
+) -> subprocess.CompletedProcess[bytes]:
     """Helper function to run a subprocess command and handle common errors."""
     env = env or {}
     try:
@@ -204,17 +193,16 @@ async def run_command(
 
                 output, errors = stream_contents
                 if check and process.returncode != 0:
-                    raise subprocess.CalledProcessError(cast(int, process.returncode), command, output, errors)
+                    raise subprocess.CalledProcessError(process.returncode or 0, command, output, errors)
 
                 if SHOW_SUCCESS_STATUS.get():
                     console.print(f"{message} [[green]DONE[/green]]")
-                return subprocess.CompletedProcess(command, cast(int, process.returncode), output, errors)
+                return subprocess.CompletedProcess(command, process.returncode or 0, output, errors)
     except FileNotFoundError:
-        if ignore_missing:
-            return None
         console.print(f"{message} [[red]ERROR[/red]]")
         tool_name = command[0]
         console.print(f"[red]Error: {tool_name} is not installed. Please install {tool_name} first.[/red]")
+        sys.exit(1)
     except subprocess.CalledProcessError as e:
         console.print(f"{message} [[red]ERROR[/red]]")
         err_console.print(f"[red]Exit code: {e.returncode} [/red]")
@@ -251,6 +239,7 @@ def verbosity(verbose: bool, show_success_status: bool = True):
     IN_VERBOSITY_CONTEXT.set(True)
     token = VERBOSE.set(verbose)
     token_command_status = SHOW_SUCCESS_STATUS.set(show_success_status)
+    capture: Capture | None = None
     try:
         with err_console.capture() if not verbose else contextlib.nullcontext() as capture:
             yield
